package binarization.data;

/**
 * Implementacao esqueletal da imagens binaria. Somente os acessores
 * dos pixels e do tamanho devem ser definidos.
 *
 * @author denis
 * @see IBinaryImage
 * @see AbstractImage
 * @see AbstractGrayLevelImage
 */
public abstract class AbstractBinaryImage extends AbstractImage implements IBinaryImage {

	@Override
	public abstract ImageSize size();

	@Override
	public abstract Pixel pixelAtUnchecked(int x, int y);

	@Override
	public IBinaryImage windowOf(ImagePoint center, ImageSize size) {
		return new BinaryWindow(super.windowOf(center, size));
	}

	@Override
	public IBinaryImage complement() {
		return new BinaryComplement(this);
	}

	/**
	 * Janela de uma imagem binaria. Utiliza a janela da superclasse.
	 * Esta classe e definida somente para que possa herdar desta classe abstrata.
	 */
	private static class BinaryWindow extends AbstractBinaryImage {

		private final IImage window;

		private BinaryWindow(IImage window) {
			this.window = window;
		}

		@Override
		public ImageSize size() {
			return window.size();
		}

		@Override
		public Pixel pixelAtUnchecked(int x, int y) {
			return window.pixelAtUnchecked(x, y);
		}
	}

	/**
	 * Imagem que complementa uma imagem binaria dada.
	 */
	private static class BinaryComplement extends AbstractBinaryImage {

		private final IBinaryImage original;

		private BinaryComplement(IBinaryImage original) {
			this.original = original;
		}

		@Override
		public ImageSize size() {
			return original.size();
		}

		@Override
		public Pixel pixelAtUnchecked(int x, int y) {
			return original.pixelAtUnchecked(x, y).isBlack() ? Pixel.ofWhite() : Pixel.ofBlack();
		}

		@Override
		public IBinaryImage complement() {
			return original;
		}
	}
}
