package binarization.data;

/**
 * Interface que define uma imagem.
 *
 * @author denis
 * @see IBinaryImage
 * @see IGrayLevelImage
 * @see AbstractImage
 * @see Pixel
 * @see ImageSize
 */
public interface IImage {

	/**
	 * Devolve {@code true} caso a imagem seja vazia. A imagem vazia deve
	 * possuir tamanho vazio.
	 * 
	 * @return {@code true} caso a imagem seja vazia
	 */
	boolean isEmpty();

	/**
	 * Devolve o tamanho desta imagem.
	 * 
	 * @return o tamanho desta imagem
	 */
	ImageSize size();

	/**
	 * Devolve o pixel no ponto dado.
	 *
	 * @param p o ponto de onde se quer o pixel
	 * @return o pixel no ponto dado
	 * @throws IndexOutOfBoundsException se o ponto estiver fora da imagem
	 */
	Pixel pixelAt(ImagePoint p);

	/**
	 * Devolve o pixel no ponto (x, y) dado. Util para varreduras sobre a imagem.
	 * 
	 * <p>Nao verifica se o ponto e valido.</p>
	 *
	 * @param x a coordenada horizontal do ponto de onde se quer o pixel
	 * @param y a coordenada vertical do ponto de onde se quer o pixel
	 * @return o pixel no ponto (x, y) dado
	 */
	Pixel pixelAtUnchecked(int x, int y);

	/**
	 * Devolve a interseccao da janela retangular de ponto central e tamanho dados,
	 * com a imagem atual. O ponto central deve estar contido na imagem, e o 
	 * tamanho tem que ter dimensoes impares, para que o centro esteja bem definido.
	 * 
	 * <p>Em outras palavras, se a janela estiver totalmente contida dentro da
	 * imagem, ela possuira o ponto central dado e o tamanho especificado;
	 * caso contrario, ela devolvera a janela dos pontos pertencentes aa janela
	 * especificada e a imagem de origem.</p>
	 * 
	 * <p>Tal flexibilidade permite que parte da janela especificada esteja fora
	 * da imagem original, e ainda assim seja possivel obter uma janela plausivel,
	 * mesmo que de tamanho menor.</p>
	 * 
	 * <p>Se o ponto central estiver fora da imagem ou o tamanho nao possuir
	 * dimensoes impares, uma excecao devera ser lancada.</p>
	 * 
	 * @param center o ponto central da janela
	 * @param size o tamanho da janela
	 * @return a interseccao da janela especificada com esta imagem
	 * @throws IndexOutOfBoundsException caso o ponto central esteja fora da imagem
	 * @throws IllegalArgumentException caso o tamanho nao possua dimensoes impares
	 */
	IImage windowOf(ImagePoint center, ImageSize size);
}
