package binarization.data;

/**
 * Implementacao simples de um histograma acumulado.
 * 
 * <p>Imutavel, e nao pode ser herdada fora do pacote para garantir sua
 * imutabilidade.</p>
 * 
 * @author denis
 */
class SimpleAccumulatedHistogram implements IAccumulatedHistogram {

	private final double[] values;
	private final int order;

	SimpleAccumulatedHistogram(double[] values, int order) {
		this.values = values;
		this.order = order;
	}

	@Override
	public double valueAt(int intensity) {
		if (intensity < 0 || intensity > maxIntensity()) {
			throw new IndexOutOfBoundsException("Intensity given out of range: [0, "
					+ maxIntensity() + "]");
		}
		return values[intensity];
	}

	@Override
	public int maxIntensity() {
		return values.length - 1;
	}

	@Override
	public int order() {
		return order;
	}
}
