package binarization.examples;

import binarization.IBinaryImageMetric;
import binarization.data.IBinaryImage;
import binarization.data.Images;

/**
 * Programa que avalia as imagens dadas (GT, binarizada, GT esqueleto) atraves
 * de cada metrica implementada.
 * 
 * @author denis
 */
public class ExampleMetricsOnce {

	/**
	 * Garante a nao-instanciabilidade da classe.
	 */
	private ExampleMetricsOnce() {
	}

	/**
	 * Ponto de entrada do programa. Imprime o resultado das metricas na saida padrao.
	 * 
	 * @param args args[0] e o arquivo GT, [1] e a binarizada, [2], se houver, e a GT esqueleto
	 */
	public static void main(String[] args) {
		if (args.length < 2) {
			System.out.println("Requer ground truth e o arquivo binarizado como parametros.");
			System.exit(-1);
		}
		final boolean hasSkeletonized = args.length > 2;

		System.out.println("Ground Truth: " + args[0]);
		System.out.println("Binarized: " + args[1]);
		if (hasSkeletonized) {
			System.out.println("Skeletonized GT: " + args[2]);
		}
		System.out.println();

		final IBinaryImage groundTruth = Images.loadBinaryImage(args[0]);
		final IBinaryImage binarized = Images.loadBinaryImage(args[1]);
		final IBinaryImage skeletonizedGT = (hasSkeletonized)
				? Images.loadBinaryImage(args[2])
				: Images.emptyBinaryImage();

		final Iterable<IBinaryImageMetric> metrics = (hasSkeletonized)
				? Metrics.getAllMetricsWithPFM()
				: Metrics.getAllMetrics();

		for (IBinaryImageMetric metric : metrics) {
			final double evaluation = metric.evaluate(groundTruth, binarized, skeletonizedGT);

			System.out.println(metric.getLabel() + ": " + metric.getFormat().format(evaluation));
		}

	}
}
