package binarization.examples;

import binarization.IBinarizationMethod;
import binarization.methods.NiblackMethod;
import binarization.methods.OtsuMethod;
import binarization.methods.SauvolaMethod;
import binarization.methods.SuMethod;
import binarization.methods.WhiteMethod;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Classe utilitaria dos metodos.
 *
 * @author denis
 */
class Methods {

	private static final int WINDOW = 15;
	private static final List<IBinarizationMethod> methods = Collections.unmodifiableList(
			Arrays.<IBinarizationMethod>asList(
			OtsuMethod.INSTANCE,
			new NiblackMethod(WINDOW),
			new SauvolaMethod(WINDOW),
			new WhiteMethod(WINDOW, 1.2),
			new SuMethod(8, 32)));

	/**
	 * Privado para garantir a nao-instanciabilidade da classe.
	 */
	private Methods() {
	}

	/**
	 * Devolve todos as metodos suportados que estao implementados no pacote.
	 *
	 * @return todos as metodos suportados que estao implementados no pacote.
	 */
	static List<IBinarizationMethod> getAllMethods() {
		return methods;
	}
}
