package binarization.examples;

import binarization.IBinaryImageMetric;
import binarization.metrics.DistanceReciprocalDistortionMetric;
import binarization.metrics.PeakSignalToNoiseRatio;
import binarization.metrics.NegativeRateMetric;
import binarization.metrics.FMeasure;
import binarization.metrics.MisclassificationPenaltyMetric;
import binarization.metrics.PseudoFMeasure;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Classe utilitaria nao-instanciavel que prove metodos estaticos auxiliares
 * para as metricas.
 *
 * @author denis
 */
class Metrics {

	private static final List<IBinaryImageMetric> METRICS = Collections.unmodifiableList(
			Arrays.<IBinaryImageMetric>asList(
			FMeasure.INSTANCE,
			PeakSignalToNoiseRatio.INSTANCE,
			DistanceReciprocalDistortionMetric.DEFAULT,
			NegativeRateMetric.INSTANCE,
			MisclassificationPenaltyMetric.INSTANCE));
	private static final List<IBinaryImageMetric> METRICS_WITH_PFM = Collections.unmodifiableList(
			Arrays.<IBinaryImageMetric>asList(
			FMeasure.INSTANCE,
			PseudoFMeasure.INSTANCE,
			PeakSignalToNoiseRatio.INSTANCE,
			DistanceReciprocalDistortionMetric.DEFAULT,
			NegativeRateMetric.INSTANCE,
			MisclassificationPenaltyMetric.INSTANCE));

	/**
	 * Garante a nao-instanciabilidade da classe.
	 */
	private Metrics() {
	}

	/**
	 * Devolve todas as metricas que estao implementadas no pacote.
	 *
	 * @return todas as metricas que estao implementadas no pacote
	 */
	static List<IBinaryImageMetric> getAllMetrics() {
		return METRICS;
	}

	/**
	 * Devolve todas as metricas que estao implementadas no pacote.
	 *
	 * @return todas as metricas que estao implementadas no pacote
	 */
	static List<IBinaryImageMetric> getAllMetricsWithPFM() {
		return METRICS_WITH_PFM;
	}
}
