package binarization.metrics;

import binarization.IBinaryImageMetric;
import binarization.data.IBinaryImage;
import binarization.data.Pixel;
import binarization.data.util.BinaryImageOperator;
import binarization.data.util.GridMarker;
import binarization.util.Comparators;
import java.text.Format;
import java.text.NumberFormat;
import java.util.Comparator;

/**
 * 
 *
 * @author denis
 */
public enum MisclassificationPenaltyMetric implements IBinaryImageMetric {

	INSTANCE;

	@Override
	public double evaluate(IBinaryImage groundTruth, IBinaryImage binarized) {
		final GridMarker distances =
				BinaryImageOperator.of(groundTruth).outline().getEuclidianDistanceTransform();

		long normalizationFactor = 0;
		long mpfn = 0;
		long mpfp = 0;
		for (int x = 0; x < groundTruth.size().width(); x++) {
			for (int y = 0; y < groundTruth.size().height(); y++) {

				final Pixel pixelGT = groundTruth.pixelAtUnchecked(x, y);
				final Pixel pixelBin = binarized.pixelAtUnchecked(x, y);

				if (pixelGT.isBlack() && pixelBin.isWhite()) {
					mpfn += distances.get(x, y);
				}

				if (pixelGT.isWhite() && pixelBin.isBlack()) {
					mpfp += distances.get(x, y);
				}

				normalizationFactor += distances.get(x, y);
			}
		}

		return (mpfp + mpfn) / (2.0 * normalizationFactor);
	}

	@Override
	public double evaluate(IBinaryImage groundTruth, IBinaryImage binarized, IBinaryImage skeletonizedGT) {
		//nao utiliza a terceira imagem
		return evaluate(groundTruth, binarized);
	}

	@Override
	public String getLabel() {
		return "MPM";
	}

	@Override
	public Format getFormat() {
		//NumberFormat e mutavel, portanto necessita de copia defensiva
		final NumberFormat format = NumberFormat.getInstance();
		format.setMinimumFractionDigits(6);

		return format;
	}

	@Override
	public Comparator<Double> getResultComparator() {
		return Comparators.DECREASING;
	}

	@Override
	public String toString() {
		return "Misclassification Penalty Metric";
	}
}
